abelfunctions: Computing with Abelian functions, Riemann surfaces, and algebraic curves
=======================================================================================

Description
-----------

A Sage library for computing with Abelian functions, Riemann surfaces, and algebraic curves.

License
-------

MIT

Upstream Contact
----------------

https://github.com/abelfunctions/abelfunctions
